# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commondata.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='commondata.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x63ommondata.proto\"\x1e\n\x0cquery_params\x12\x0e\n\x06params\x18\x01 \x01(\t\"\x18\n\x08\x64\x61ta_ret\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1d\n\x0b\x66unc_params\x12\x0e\n\x06params\x18\x01 \x01(\t\"\x18\n\x08\x66unc_ret\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t25\n\x0b\x44\x42Interface\x12&\n\x08query_db\x12\r.query_params\x1a\t.data_ret\"\x00\x32\x36\n\rFuncInterface\x12%\n\x08run_func\x12\x0c.func_params\x1a\t.func_ret\"\x00\x62\x06proto3'
)




_QUERY_PARAMS = _descriptor.Descriptor(
  name='query_params',
  full_name='query_params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='query_params.params', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20,
  serialized_end=50,
)


_DATA_RET = _descriptor.Descriptor(
  name='data_ret',
  full_name='data_ret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='data_ret.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=76,
)


_FUNC_PARAMS = _descriptor.Descriptor(
  name='func_params',
  full_name='func_params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='func_params.params', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=107,
)


_FUNC_RET = _descriptor.Descriptor(
  name='func_ret',
  full_name='func_ret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='func_ret.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=133,
)

DESCRIPTOR.message_types_by_name['query_params'] = _QUERY_PARAMS
DESCRIPTOR.message_types_by_name['data_ret'] = _DATA_RET
DESCRIPTOR.message_types_by_name['func_params'] = _FUNC_PARAMS
DESCRIPTOR.message_types_by_name['func_ret'] = _FUNC_RET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

query_params = _reflection.GeneratedProtocolMessageType('query_params', (_message.Message,), {
  'DESCRIPTOR' : _QUERY_PARAMS,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:query_params)
  })
_sym_db.RegisterMessage(query_params)

data_ret = _reflection.GeneratedProtocolMessageType('data_ret', (_message.Message,), {
  'DESCRIPTOR' : _DATA_RET,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:data_ret)
  })
_sym_db.RegisterMessage(data_ret)

func_params = _reflection.GeneratedProtocolMessageType('func_params', (_message.Message,), {
  'DESCRIPTOR' : _FUNC_PARAMS,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:func_params)
  })
_sym_db.RegisterMessage(func_params)

func_ret = _reflection.GeneratedProtocolMessageType('func_ret', (_message.Message,), {
  'DESCRIPTOR' : _FUNC_RET,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:func_ret)
  })
_sym_db.RegisterMessage(func_ret)



_DBINTERFACE = _descriptor.ServiceDescriptor(
  name='DBInterface',
  full_name='DBInterface',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=135,
  serialized_end=188,
  methods=[
  _descriptor.MethodDescriptor(
    name='query_db',
    full_name='DBInterface.query_db',
    index=0,
    containing_service=None,
    input_type=_QUERY_PARAMS,
    output_type=_DATA_RET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DBINTERFACE)

DESCRIPTOR.services_by_name['DBInterface'] = _DBINTERFACE


_FUNCINTERFACE = _descriptor.ServiceDescriptor(
  name='FuncInterface',
  full_name='FuncInterface',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=190,
  serialized_end=244,
  methods=[
  _descriptor.MethodDescriptor(
    name='run_func',
    full_name='FuncInterface.run_func',
    index=0,
    containing_service=None,
    input_type=_FUNC_PARAMS,
    output_type=_FUNC_RET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FUNCINTERFACE)

DESCRIPTOR.services_by_name['FuncInterface'] = _FUNCINTERFACE

# @@protoc_insertion_point(module_scope)
